'use strict';

var path = require('path');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var path__default = /*#__PURE__*/_interopDefaultLegacy(path);

const eslintConfig = {
  parser: 'babel-eslint',
  extends: ['prettier'],
  plugins: ['prettier'],
  env: {
    browser: true,
  },
};

var eslintConfig_1 = eslintConfig;

var _prettierrc = {
  semi: false,
  singleQuote: true,
};

/* eslint-disable no-console */

const isDevelopment = process.env.NODE_ENV !== 'production';

const webpackConfig = {
  entry: './src/index.js',
  mode: isDevelopment ? 'development' : 'production',
  infrastructureLogging: {
    appendOnly: true,
    level: 'warn',
  },
  output: {
    filename: 'main.js',
    path: path__default['default'].resolve(__dirname, 'dist'),
  },
  devServer: {
    compress: true,
    port: 3000,
    host: '0.0.0.0',
    hot: true,
    historyApiFallback: true,
    watchFiles: ['src/**/.js'],
    static: {
      directory: path__default['default'].join(__dirname, 'dist'),
    },
    onListening: function onListening(server) {
      const host = process.env.HOST || 'localhost';
      const address = `http://${host}:${server.port}`;
      console.clear();
      console.log();
      console.log();
      console.log('   Listening on:', address);
      console.log();
    },
  },
  module: {
    rules: [
      {
        enforce: 'pre',
        test: /\.js$/,
        exclude: /node_modules/,
        loader: 'eslint-loader',
      },
      {
        test: /\.js$/,
        exclude: /node_modules/,
        loader: 'babel-loader',
        options: {
          cacheDirectory: true,
          presets: ['@babel/preset-react', '@babel/preset-env'],
          plugins: [
            '@babel/plugin-proposal-object-rest-spread',
            '@babel/plugin-transform-react-jsx',
            '@babel/plugin-proposal-class-properties',
          ],
        },
      },
    ],
  },
};

var webpackConfig_1 = webpackConfig;

var lib = {
  eslint: eslintConfig_1,
  prettier: _prettierrc,
  webpack: webpackConfig_1,
};

module.exports = lib;
//# sourceMappingURL=index.cjs.js.map
